@@ -19,7 +19,7 @@ use Types::Standard -types;
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.1.3';
+our $VERSION = 'v0.1.4';
 
 
 sub mvp_multivalue_args { qw/ add remove / }
@@ -66,7 +66,10 @@ sub gather_files {
     $mms->remove('^weaver.ini$');
     $mms->remove('^xt/');
 
-    $mms->add('cpanfile\.snapshot$') if any { $_->name eq 'cpanfile' } @files;
+    if ( any { $_->name eq 'cpanfile' } @files ) {
+        $mms->add('cpanfile\.snapshot$');
+        $mms->add('local/');
+    }
     $mms->add('_alien/') if any { $_->name eq 'alienfile' } @files;
 
     foreach my $file (@{ $self->add }) {
@@ -106,14 +109,14 @@ Dist::Zilla::Plugin::Generate::ManifestSkip - generate a MANIFEST.SKIP file for
 
 =head1 VERSION
 
-version v0.1.3
+version v0.1.4
 
 =head1 SYNOPSIS
 
 In your F<dist.ini> file:
 
   [Generate::ManifestSkip]
-  :version = v0.1.2
+  :version = v0.1.3
 
 =head1 DESCRIPTION
 
@@ -154,7 +157,7 @@ will be added.
 =head2 remove
 
 This removes a regular expression from the L</skipfile>. Note that it
-must the expression from L<Module::Manifest::Skip>.
+must exactly match the expression used by L<Module::Manifest::Skip>.
 
 By default, the following files are already removed from the skipfile:
 
